==> haskell-descriptive-0.9.4-10-armv7h.pkg.tar.xz: usr/share/haskell/haskell-descriptive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-5b20db39d8b82847194f317f7419d9b2
key: descr_LyCkz3iKhnrJIfMKuJz2ai
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-LyCkz3iKhnrJIfMKuJz2ai
depends:
    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.4-13-armv7h.pkg.tar.xz: usr/share/haskell/haskell-descriptive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-60d90b160af650ae9ec32cf13be1e1df
key: descr_CNQrVS6OKMhHV4CYjJdS3B
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-CNQrVS6OKMhHV4CYjJdS3B
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.2.1-3dea194c07c9b02982b78a82398333cc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
